# Changelog

## [0.7.0](https://github.com/chrislemke/sk-transformers/compare/v0.6.3...v0.7.0) (2023-01-06)


### Features

* add left_join_transformer ([#29](https://github.com/chrislemke/sk-transformers/issues/29)) ([31fbde0](https://github.com/chrislemke/sk-transformers/commit/31fbde02aada7c81236d4775b9ccc7f29510ac2f))


### Bug Fixes

* add `numpy` as a possible prefix ([#31](https://github.com/chrislemke/sk-transformers/issues/31)) ([8fec7d3](https://github.com/chrislemke/sk-transformers/commit/8fec7d30b4ed8415b090182c7a27d09310f070a2))


### CI/CD

* fix code-cov action ([f2be192](https://github.com/chrislemke/sk-transformers/commit/f2be1920fb037a3b5e8e215347613035df4dd441))


### Maintenance

* general improvements ([85596c2](https://github.com/chrislemke/sk-transformers/commit/85596c2526accb6bda9e7e5efd959fbf8ea28588))
* use swifter to speed up pandas apply ([#28](https://github.com/chrislemke/sk-transformers/issues/28)) ([53684e9](https://github.com/chrislemke/sk-transformers/commit/53684e912fa752e0c2902e99b93fa45dacda2613))


### Documentation

* add new project logo ([#32](https://github.com/chrislemke/sk-transformers/issues/32)) ([93e277b](https://github.com/chrislemke/sk-transformers/commit/93e277b6b7c26e7fdb1919512bdc188b2d51254f))
* add playground notebook ([#30](https://github.com/chrislemke/sk-transformers/issues/30)) ([681eaf9](https://github.com/chrislemke/sk-transformers/commit/681eaf92e3cf41a9fb93b446b2b5c21877ddf5f1))

## [0.6.3](https://github.com/chrislemke/sk-transformers/compare/v0.6.2...v0.6.3) (2023-01-04)


### Features

* deep transformer module ([#24](https://github.com/chrislemke/sk-transformers/issues/24)) ([fd266cf](https://github.com/chrislemke/sk-transformers/commit/fd266cf10c629cc5c5d33528006480fd5094cc96))

## [0.6.2](https://github.com/chrislemke/sk-transformers/compare/v0.6.1...v0.6.2) (2022-12-22)


### Documentation

* improve contributing file ([3b5287b](https://github.com/chrislemke/sk-transformers/commit/3b5287b1cd326b65331b086b4d2c8275a3dd170a))


### CI/CD

* improve the release process ([096f3b2](https://github.com/chrislemke/sk-transformers/commit/096f3b2482688ab561bf3afa4b6d8b98e1736186))

## [0.6.1](https://github.com/chrislemke/sk-transformers/compare/v0.6.0...v0.6.1) (2022-12-22)


### Bug Fixes

* wrong formatting in readme.md ([425f4ed](https://github.com/chrislemke/sk-transformers/commit/425f4ed1cf173ffad7534dae035528bc2fa81072))


### Documentation

* improve the usability ([4190cd7](https://github.com/chrislemke/sk-transformers/commit/4190cd7c356b540e788dfe5930ab198a1c5a13fe))

## [0.6.0](https://github.com/chrislemke/sk-transformers/compare/v0.5.7...v0.6.0) (2022-12-22)


### Features

* add scripts to improve the release process 🚀 ([54a9dfe](https://github.com/chrislemke/sk-transformers/commit/54a9dfeda3c4448502206f5e3181f69da17df9a5))
